..
    Copyright (C) 2019 Esteban J. Garcia Gabancho.

    Invenio-SAML is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


API Docs
========

.. automodule:: invenio_saml.ext
   :members:

Default handlers
----------------

.. automodule:: invenio_saml.handlers
   :members:
